pyparsing.pyparsing.Dict

Package pyparsing :: Module pyparsing :: Class Dict |
[frames | no frames]

## Type Dict

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
             TokenConverter --+
                              |
                             Dict

Converter to return a repetitive expression as a list, but also as a dictionary. Each element can also be referenced using the first token in the expression as its key. Useful for tabular report scraping when the first column can be used as a item key.

Method Summary
| `__init__(self, exprs)`
| `postParse(self, instring, loc, tokenlist)`
Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `parseImpl`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `getException`, `parseFile`, `parseString`, `parseWithTabs`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net